# UEQ+ Erweiterung - Dashboard

## Table of Contents
<!-- TOC -->
* [Table of Contents](#table-of-contents)
* [Description](#description)
* [Project Structure](#project-structure)
* [Roadmap](#roadmap)
* [Used scales in the questionnaire](#used-scales-in-the-questionnaire)
<!-- TOC -->

## Description

This purpose of this data repository is introduces new product categories, Dashboard and Virtual Reality, to the User
Experience Questionnaire ([UEQ+](https://ueqplus.ueq-research.org/Material/UEQ+_Handbook_V2.pdf)).
The UEQ+ is a standardized questionnaire that provides a set of scales considered to be most important for evaluating
the user experience of a product family.
We have conducted a quantitative study to determine the most important scales.
For this purpose, a procedure that had been used in previous studies to determine the most important User Experience
scales for previously released categories (Games and Learning Platforms) was reproduced.
These product categories were integrated to ensure that the conditions of our study were similar.
The results are presented, critically discussed, and compared with previous studies in a scientific publication.

To reproduce all plots, run:
````
pip install -r requirements.txt
python src/main.py
````

The notebook is outdated.

## Project Structure

The folder structure is based on
[Good enough practices in scientific computing](https://doi.org/10.1371/journal.pcbi.1005510).

```
| -- data                 # folder for raw (mostly survey) data and questionnaire
| -- results              # results of the survey and visualizations
| -- src                  # possible source code to compute the results
```

## Roadmap

- [x] create questionnaire
- [x] pretest
- [x] conduct survey
    - [x] start date: 05.07.22
    - [x] final date: 30.11.22
- [x] upload data
    - [x] subset 04.08.22
    - [x] final data 25.01.23
- [x] analyse data and publish results
- [x] produce publication - MuC

## Used scales in the questionnaire

The list of scales and their corresponding questionnaire sources are presented below.

| Items                                             | In [UEQ+](https://ueqplus.ueq-research.org/Material/UEQ+_Handbook_V2.pdf) | In the [Paper](https://dl.gi.de/bitstream/handle/20.500.12116/5770/2017_UP_002.pdf?sequence=2&isAllowed=y) | used in questionnaire | Erklärender Satz                                                                                                |
|---------------------------------------------------|:-------------------------------------------------------------------------:|:----------------------------------------------------------------------------------------------------------:|-----------------------|-----------------------------------------------------------------------------------------------------------------|
| Akustik (Acoustics)                               |                                     ✔                                     |                                                     ❌                                                      | ✔                     | Die beim Betrieb des Produkts entstehenden Geräusche sind leise, sanft und wohlklingend.                        |
| Anpassbarkeit (Adaptability)                      |                                     ✔                                     |                                                     ✔                                                      | ✔                     |                                                                                                                 |
| Attraktivität (Attractiveness)                    |                                     ✔                                     |                                                     ❌                                                      | ✔                     | Insgesamt empfinde ich das Produkt als angenehm, sympathisch und erfreulich.                                    |
| Antwortverhalten (Response behavior)              |                                     ✔                                     |                                                     ❌                                                      | ❌                     | --                                                                                                              |
| Antwortqualität (Response quality)                |                                     ✔                                     |                                                     ❌                                                      | ❌                     | --                                                                                                              |
| Durchschaubarkeit (Perspicuity)                   |                                     ✔                                     |                                                     ✔                                                      | ✔                     |                                                                                                                 |
| Effizienz (Efficiency)                            |                                     ✔                                     |                                                     ✔                                                      | ✔                     |                                                                                                                 |
| Haptik (Haptics)                                  |                                     ✔                                     |                                                     ❌                                                      | ✔                     | Die Oberfläche des Produkts empfinde ich als stabil und angenehm anzufassen. Die Flächen wirken und rutschfest. |
| Identität                                         |                                     ❌                                     |                                                     ✔                                                      | ✔                     | Die Oberfläche des Produkts empfinde ich als stabil und angenehm anzufassen. Die Flächen wirken und rutschfest. |
| Immersion (Immersion)                             |                                     ❌                                     |                                                     ✔                                                      | ✔                     |                                                                                                                 |
| Inhaltsqualität (Quality of Content)              |                                     ✔                                     |                                                     ✔                                                      | ✔                     |                                                                                                                 |
| Intuitive Bedienung (Intuitive use)               |                                     ✔                                     |                                                     ✔                                                      | ✔                     |                                                                                                                 |
| Nützlichkeit (Usefulness)                         |                                     ✔                                     |                                                     ✔                                                      | ✔                     |                                                                                                                 |
| Originalität (Novelty)                            |                                     ✔                                     |                                                     ✔                                                      | ✔                     |                                                                                                                 |
| Schönheit                                         |                                     ❌                                     |                                                     ✔                                                      | ✔                     |                                                                                                                 |
| Steuerbarkeit (Dependability)                     |                                     ✔                                     |                                                     ✔                                                      | ✔                     |                                                                                                                 |
| Stimulation (Stimulation)                         |                                     ✔                                     |                                                     ✔                                                      | ✔                     |                                                                                                                 |
| Übersichtlichkeit (Clarity)                       |                                     ✔                                     |                                                     ✔                                                      | ✔                     |                                                                                                                 |
| Verbundenheit                                     |                                     ❌                                     |                                                     ✔                                                      | ✔                     |                                                                                                                 |
| Vertrauenswürdigkeit (Trustworthiness of Content) |                                     ✔                                     |                                                     ❌                                                      | ✔                     | Die Informationen und Daten, die mir das Produkt bereitstellt sind nützlich, glaubwürdig und seriös.            |
| Visuelle Ästhetik/Schönheit  (Aesthetics)         |                                     ✔                                     |                                                     ✔                                                      | ✔                     | Die visuelle Gestaltung des Produkts empfinde ich als schön, stilvoll und ansprechend.                          |
| Verständnis (Comprehensibility)                   |                                     ✔                                     |                                                     ❌                                                      | ❌                     | --                                                                                                              |
| Vertrauen (Trust)                                 |                                     ✔                                     |                                                     ✔                                                      | ✔                     |                                                                                                                 |
| Wertigkeit (Value)                                |                                     ✔                                     |                                                     ✔                                                      | ✔                     |                                                                                                                 |
